| getReport | R Documentation |
This function queries the DistillerSR API to retrieve a saved report associated with a given project ID. It requires user authentication and a valid API endpoint URL. The result is a dataframe containing metadata about the saved report.
getReport(
projectId,
reportId,
format = c("excel", "csv"),
distillerInstanceUrl = Sys.getenv("DISTILLER_INSTANCE_URL"),
distillerToken,
timeout = 1800,
attempts = 1,
retryEach = 600,
verbose = TRUE
)
projectId |
|
reportId |
|
format |
|
distillerInstanceUrl |
By default: Sys.getenv("DISTILLER_INSTANCE_URL"). |
distillerToken |
|
timeout |
By default: 1800 seconds (30 minutes). |
attempts |
By default: 1 attempt. |
retryEach |
By default: 600 seconds (10 minutes). |
verbose |
By default: TRUE. |
A data frame containing the Distiller report as designed within DistillerSR.
getAuthenticationToken
getProjects
getReports
## Not run:
distillerToken_ <- getAuthenticationToken()
projects_ <- getProjects(distillerToken = distillerToken_)
reports_ <- getReports(
projectId = projects_$id[1],
distillerToken = distillerToken_)
report_ <- getReport(
projectId = projects_$id[1],
reportID = reports_$id[7],
format = "csv",
distillerToken = distillerToken_)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.