| getProjects | R Documentation |
This function queries the DistillerSR API to retrieve the list of projects accessible to the authenticated user. It requires an authentication token and a valid API instance URL. The result is a dataframe listing available projects.
getProjects(
distillerInstanceUrl = Sys.getenv("DISTILLER_INSTANCE_URL"),
distillerToken,
timeout = 1800
)
distillerInstanceUrl |
By default: Sys.getenv("DISTILLER_INSTANCE_URL"). |
distillerToken |
|
timeout |
By default: 1800 seconds (30 minutes). |
A tibble with four columns:
id: The project ID.
name: The name of the project.
de_project_id.
is_hidden.
getAuthenticationToken
## Not run:
distillerToken_ <- getAuthenticationToken()
projects_ <- getProjects(distillerToken = distillerToken_)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.