| getReports | R Documentation |
This function queries the DistillerSR API to retrieve the list of saved reports associated with a given project ID. It requires user authentication and a valid API endpoint URL. The result is a dataframe containing metadata about each saved report.
getReports(
projectId,
distillerInstanceUrl = Sys.getenv("DISTILLER_INSTANCE_URL"),
distillerToken,
timeout = 1800
)
projectId |
|
distillerInstanceUrl |
By default: Sys.getenv("DISTILLER_INSTANCE_URL"). |
distillerToken |
|
timeout |
By default: 1800 seconds (30 minutes). |
A tibble with four columns:
id: The ID of the saved report.
name: The name of the report.
date: The creation date of the report.
view: The format of the report (e.g., html, csv, excel).
getAuthenticationToken
getProjects
## Not run:
distillerToken_ <- getAuthenticationToken()
projects_ <- getProjects(distillerToken = distillerToken_)
reports_ <- getReports(
projectId = projects_$id[1],
distillerToken = distillerToken_)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.